<?php
/**
 * techieblog functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package techieblog
 */

if (!function_exists('techieblog_setup')) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function techieblog_setup()
	{
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on techieblog, use a find and replace
		 * to change 'techieblog' to the name of your theme in all the template files.
		 */
		load_theme_textdomain('techieblog', get_template_directory() . '/languages');

		// Add default posts and comments RSS feed links to head.
		add_theme_support('automatic-feed-links');

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support('title-tag');

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support('post-thumbnails');

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(array(
			'primary' => esc_html__('Primary', 'techieblog'),
		));

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support('html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		));

		// Set up the WordPress core custom background feature.
		add_theme_support('custom-background', apply_filters('techieblog_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		)));
	}
endif;
add_action('after_setup_theme', 'techieblog_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function techieblog_content_width()
{
	$GLOBALS['content_width'] = apply_filters('techieblog_content_width', 640);
}

add_action('after_setup_theme', 'techieblog_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function techieblog_widgets_init()
{
	register_sidebar(array(
		'name' => esc_html__('Sidebar', 'techieblog'),
		'id' => 'sidebar-1',
		'description' => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name' => esc_html__('Sidebar Footer', 'techieblog'),
		'id' => 'sidebar-2',
		'description' => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget' => '</section>',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));
}

add_action('widgets_init', 'techieblog_widgets_init');

/**
 * Do not use front-page.php for homepage if a Static Page is used.
 */
function techieblog_ignore_front_page_template( $template ) {
	return !is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'techieblog_ignore_front_page_template' );

/**
 * Enqueue scripts and styles.
 */
function techieblog_scripts()
{
	wp_enqueue_style('bootstrap-css', get_template_directory_uri() . '/css/bootstrap.min.css', '3.3.7');
	wp_enqueue_style('fontawesome-css', get_template_directory_uri() . '/css/font-awesome.min.css', '4.7.0');
	wp_enqueue_style('techieblog-style', get_stylesheet_uri());

	// Google Fonts
	wp_enqueue_style('google-fonts', "https://fonts.googleapis.com/css?family=Iceland%7CRoboto:300,300i,700&amp;subset=latin,latin-ext", array(), '1.0');

	wp_enqueue_script('isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array('jquery'), '2.2.2', true);
	wp_enqueue_script('magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array('jquery'), '1.1.0', true);
	wp_enqueue_script('techieblog-customjs', get_template_directory_uri() . '/js/custom.js', array('jquery'), '1.0', true);
	wp_localize_script('techieblog-customjs', 'techieblog', array(
		'ajax_url' => admin_url('admin-ajax.php'),
		'contact_success_message' => __('Your message has been sent. Thank you!', 'techieblog')
	));

	wp_enqueue_script('techieblog-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}

add_action('wp_enqueue_scripts', 'techieblog_scripts');

/**
 * Related posts
 *
 * @global object $post
 * @param array $args
 * @return
 */
function techieblog_related_posts($args = array()) {
	global $post;

	// default args
	$args = wp_parse_args($args, array(
		'post_id' => !empty($post) ? $post->ID : '',
		'taxonomy' => 'category',
		'limit' => 3,
		'post_type' => !empty($post) ? $post->post_type : 'post',
		'orderby' => 'date',
		'order' => 'DESC'
	));

	// check taxonomy
	$registered_taxonomies = get_taxonomies();

	if ( !in_array( $args['taxonomy'], $registered_taxonomies ) ) {
		return;
	}

	// post taxonomies
	$taxonomies = wp_get_post_terms($args['post_id'], $args['taxonomy'], array('fields' => 'ids'));

	if ( empty( $taxonomies ) ) {
		return;
	}

	// query
	$related_posts = get_posts(array(
		'post__not_in' => (array) $args['post_id'],
		'post_type' => $args['post_type'],
		'tax_query' => array(
			array(
				'taxonomy' => $args['taxonomy'],
				'field' => 'term_id',
				'terms' => $taxonomies
			),
		),
		'posts_per_page' => $args['limit'],
		'orderby' => $args['orderby'],
		'order' => $args['order']
	));

	include( locate_template( 'template-parts/related.php', false, false ) );

	wp_reset_postdata();
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
